@@ -30,31 +30,31 @@
 #include <netdb.h>
 
 
-void dns_setrpcent(int stayopen)
+void _dns_setrpcent(int stayopen)
 {
 }
 
 
-void dns_endrpcent(void)
+void _dns_endrpcent(void)
 {
 }
 
 
-struct rpcent *dns_getrpcent(void)
+struct rpcent *_dns_getrpcent(void)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct rpcent *dns_getrpcbyname(const char *name)
+struct rpcent *_dns_getrpcbyname(const char *name)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct rpcent *dns_getrpcbynumber(int number)
+struct rpcent *_dns_getrpcbynumber(int number)
 {
     errno = ECONNREFUSED;
     return NULL;
