@@ -33,24 +33,24 @@
 #include <shadow.h>
 
 
-void dns_setspent(void)
+void _dns_setspent(void)
 {
 }
 
 
-void dns_endspent(void)
+void _dns_endspent(void)
 {
 }
 
 
-struct spwd *dns_getspent(void)
+struct spwd *_dns_getspent(void)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct spwd *dns_getspnam(const char *name)
+struct spwd *_dns_getspnam(const char *name)
 {
     errno = ECONNREFUSED;
     return NULL;
