@@ -206,7 +206,7 @@ struct passwd *_getpwnam(const char *name)
     return pwp;
 }
 
-struct passwd *_getpwuid(int uid)
+struct passwd *_getpwuid(uid_t uid)
 {
     struct passwd *pwp;
 
