@@ -30,24 +30,24 @@
 #include <netdb/services.h>
 
 
-void nis_setservent(int stayopen)
+void _nis_setservent(int stayopen)
 {
 }
 
 
-void nis_endservent(void)
+void _nis_endservent(void)
 {
 }
 
 
-struct servent *nis_getservent(void)
+struct servent *_nis_getservent(void)
 {
     errno = ECONNREFUSED;
     return NULL;
 }
 
 
-struct servent *nis_getservbyname(const char *name,
+struct servent *_nis_getservbyname(const char *name,
 				  const char *protocol)
 {
     errno = ECONNREFUSED;
@@ -55,7 +55,7 @@ struct servent *nis_getservbyname(const char *name,
 }
 
 
-struct servent *nis_getservbyport(int port,
+struct servent *_nis_getservbyport(int port,
 				  const char *protocol)
 {
     errno = ECONNREFUSED;
