@@ -106,7 +106,7 @@ static struct sgrp *grent_parse(char *str, int len)
     return &sgrp;
 }
 
-void yp_setsgent(void)
+void _yp_setsgent(void)
 {
     rewind_flag = 1;
     if (savekey)
@@ -114,7 +114,7 @@ void yp_setsgent(void)
 }
 
 
-void yp_endsgent(void)
+void _yp_endsgent(void)
 {
     rewind_flag = 1;
     if (savekey)
@@ -122,7 +122,7 @@ void yp_endsgent(void)
 }
 
 
-struct sgrp *yp_getsgent(void)
+struct sgrp *_yp_getsgent(void)
 {
     struct sgrp *sg;
     char *map;
@@ -195,7 +195,7 @@ struct sgrp *yp_getsgent(void)
 }
 
 
-struct sgrp *yp_getsgnam(const char *name)
+struct sgrp *_yp_getsgnam(const char *name)
 {
     struct sgrp *sg;
     char *map;
