@@ -90,7 +90,7 @@ static struct rpcent *rpcent_parse(char *str, int len)
 
 
 
-void yp_setrpcent(int stayopen)
+void _yp_setrpcent(int stayopen)
 {
     rewind_flag = 1;
     if (savekey)
@@ -98,7 +98,7 @@ void yp_setrpcent(int stayopen)
 }
 
 
-void yp_endrpcent(void)
+void _yp_endrpcent(void)
 {
     rewind_flag = 1;
     if (savekey)
@@ -106,7 +106,7 @@ void yp_endrpcent(void)
 }
 
 
-struct rpcent *yp_getrpcent(void)
+struct rpcent *_yp_getrpcent(void)
 {
     struct rpcent *rpe;
     char *map;
@@ -179,7 +179,7 @@ struct rpcent *yp_getrpcent(void)
 }
 
 
-struct rpcent *yp_getrpcbyname(const char *name)
+struct rpcent *_yp_getrpcbyname(const char *name)
 {
     struct rpcent *rpp;
     char *map;
@@ -207,7 +207,7 @@ struct rpcent *yp_getrpcbyname(const char *name)
 }
 
 
-struct rpcent *yp_getrpcbynumber(int number)
+struct rpcent *_yp_getrpcbynumber(int number)
 {
     char buf[32];
     struct rpcent *rpp;
