@@ -232,6 +232,8 @@ CLIENT *ypconf_domain2client(const char *domain,
 		if (!clh)
 		    goto next;
 		
+		clh->cl_auth = authunix_create_default();
+		
 		_yp_config->server[*idx].client = clh;
 	    }
 
@@ -260,6 +262,7 @@ int ypconf_unbinddomain(char *domain)
 	{
 	    if (_yp_config->server[i].client)
 	    {
+		auth_destroy(_yp_config->server[i].client->cl_auth);
 		clnt_destroy(_yp_config->server[i].client);
 		_yp_config->server[i].client = NULL;
 	    }
